@@ -430,7 +430,7 @@ where
     fn parse_basical_numeric_value(&mut self) -> PResult<Value> {
         match cur!(self) {
             tok!("percent") => Ok(Value::Percent(self.parse()?)),
-            tok!("dimension") => Ok(Value::Unit(self.parse()?)),
+            tok!("dimension") => Ok(Value::Dimension(self.parse()?)),
             tok!("num") => Ok(Value::Number(self.parse()?)),
             _ => {
                 unreachable!()
@@ -687,11 +687,11 @@ where
     }
 }
 
-impl<I> Parse<UnitValue> for Parser<I>
+impl<I> Parse<Dimension> for Parser<I>
 where
     I: ParserInput,
 {
-    fn parse(&mut self) -> PResult<UnitValue> {
+    fn parse(&mut self) -> PResult<Dimension> {
         let span = self.input.cur_span()?;
 
         if !is!(self, Dimension) {
@@ -708,7 +708,7 @@ where
             } => {
                 let unit_len = raw_unit.len() as u32;
 
-                Ok(UnitValue {
+                Ok(Dimension {
                     span,
                     value: Number {
                         value,
@@ -719,7 +719,7 @@ where
                             Default::default(),
                         ),
                     },
-                    unit: Unit {
+                    unit: Ident {
                         span: swc_common::Span::new(
                             span.hi - BytePos(unit_len),
                             span.hi,
